<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl_NL" version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About KeePassX</source>
        <translation>Over KeePassX</translation>
    </message>
    <message>
        <source>KeePassX is distributed under the term of the GNU General Public License (GPL) version 2 or (at your option) version 3.</source>
        <translation>KeePassX wordt verspreid onder de bepalingen van de GNU General Public License (GPL) versie 2 of (als u wenst) versie 3.</translation>
    </message>
    <message>
        <source>Revision</source>
        <translation>Revisie</translation>
    </message>
    <message>
        <source>Using:</source>
        <translation>Maakt gebruik van:</translation>
    </message>
</context>
<context>
    <name>AutoType</name>
    <message>
        <source>Auto-Type - KeePassX</source>
        <translation>Auto-typen - KeePassX</translation>
    </message>
    <message>
        <source>Couldn&apos;t find an entry that matches the window title:</source>
        <translation>Kon geen element vinden dat overeenkomt met de venstertitel:</translation>
    </message>
</context>
<context>
    <name>AutoTypeAssociationsModel</name>
    <message>
        <source>Window</source>
        <translation>Venster</translation>
    </message>
    <message>
        <source>Sequence</source>
        <translation>Volgorde</translation>
    </message>
    <message>
        <source>Default sequence</source>
        <translation>Standaardvolgorde</translation>
    </message>
</context>
<context>
    <name>AutoTypeSelectDialog</name>
    <message>
        <source>Auto-Type - KeePassX</source>
        <translation>Auto-typen - KeePassX</translation>
    </message>
    <message>
        <source>Select entry to Auto-Type:</source>
        <translation>Kies element om automatisch te typen:</translation>
    </message>
</context>
<context>
    <name>ChangeMasterKeyWidget</name>
    <message>
        <source>Password</source>
        <translation>Wachtwoord</translation>
    </message>
    <message>
        <source>Enter password:</source>
        <translation>Geef wachtwoord:</translation>
    </message>
    <message>
        <source>Repeat password:</source>
        <translation>Herhaal wachtwoord:</translation>
    </message>
    <message>
        <source>Key file</source>
        <translation>Sleutelbestand</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Bladeren</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Aanmaken</translation>
    </message>
    <message>
        <source>Key files</source>
        <translation>Sleutelbestanden</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Alle bestanden</translation>
    </message>
    <message>
        <source>Create Key File...</source>
        <translation>Genereer sleutelbestand...</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <source>Unable to create Key File : </source>
        <translation>Niet mogelijk om sleutelbestand aan te maken:</translation>
    </message>
    <message>
        <source>Select a key file</source>
        <translation>Kies een sleutelbestand</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Vraag</translation>
    </message>
    <message>
        <source>Do you really want to use an empty string as password?</source>
        <translation>Weet u zeker dat u een leeg veld als wachtwoord wilt gebruiken?</translation>
    </message>
    <message>
        <source>Different passwords supplied.</source>
        <translation>Verschillende wachtwoorden opgegeven.</translation>
    </message>
    <message>
        <source>Failed to set key file</source>
        <translation>Niet gelukt het sleutelbestand in te stellen</translation>
    </message>
    <message>
        <source>Failed to set %1 as the Key file:
%2</source>
        <translation>Niet gelukt %1 als sleutelbestand in te stellen:
%2</translation>
    </message>
</context>
<context>
    <name>DatabaseOpenWidget</name>
    <message>
        <source>Enter master key</source>
        <translation>Geef hoofdsleutel</translation>
    </message>
    <message>
        <source>Key File:</source>
        <translation>Sleutelbestand:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Wachtwoord:</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Bladeren</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>Niet mogelijk om de database te openen.</translation>
    </message>
    <message>
        <source>Can&apos;t open key file</source>
        <translation>Niet mogelijk om het sleutelbestand te openen</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Alle bestanden</translation>
    </message>
    <message>
        <source>Key files</source>
        <translation>Sleutelbestanden</translation>
    </message>
    <message>
        <source>Select key file</source>
        <translation>Kies sleutelbestand</translation>
    </message>
</context>
<context>
    <name>DatabaseRepairWidget</name>
    <message>
        <source>Repair database</source>
        <translation>Database repareren</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <source>Can&apos;t open key file</source>
        <translation>Niet mogelijk om het sleutelbestand te openen</translation>
    </message>
    <message>
        <source>Database opened fine. Nothing to do.</source>
        <translation>Database werd zonder problemen geopend. Niets te doen.</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>Niet mogelijk om de database te openen.</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Gelukt</translation>
    </message>
    <message>
        <source>The database has been successfully repaired
You can now save it.</source>
        <translation>De database is met succes gerepareerd
U kunt deze nu opslaan.</translation>
    </message>
    <message>
        <source>Unable to repair the database.</source>
        <translation>Niet mogelijk om de database te repareren.</translation>
    </message>
</context>
<context>
    <name>DatabaseSettingsWidget</name>
    <message>
        <source>Database name:</source>
        <translation>Naam van de database:</translation>
    </message>
    <message>
        <source>Database description:</source>
        <translation>Beschrijving van de database:</translation>
    </message>
    <message>
        <source>Transform rounds:</source>
        <translation>Transformatierondes:</translation>
    </message>
    <message>
        <source>Default username:</source>
        <translation>Standaard gebruikersnaam:</translation>
    </message>
    <message>
        <source>Use recycle bin:</source>
        <translation>Gebruik prullenbak:</translation>
    </message>
    <message>
        <source> MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <source>Benchmark</source>
        <translation>Test</translation>
    </message>
    <message>
        <source>Max. history items:</source>
        <translation>Max. items in geschiedenis:</translation>
    </message>
    <message>
        <source>Max. history size:</source>
        <translation>Max. grootte geschiedenis:</translation>
    </message>
</context>
<context>
    <name>DatabaseTabWidget</name>
    <message>
        <source>Root</source>
        <translation>Alles</translation>
    </message>
    <message>
        <source>KeePass 2 Database</source>
        <translation>KeePass 2 Database</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Alle bestanden</translation>
    </message>
    <message>
        <source>Open database</source>
        <translation>Open database</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Waarschuwing</translation>
    </message>
    <message>
        <source>File not found!</source>
        <translation>Bestand niet gevonden!</translation>
    </message>
    <message>
        <source>Open KeePass 1 database</source>
        <translation>Open KeePass 1 database</translation>
    </message>
    <message>
        <source>KeePass 1 database</source>
        <translation>KeePass 1 database</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>Alle bestanden (*)</translation>
    </message>
    <message>
        <source>Close?</source>
        <translation>Sluiten?</translation>
    </message>
    <message>
        <source>Save changes?</source>
        <translation>Wijzigingen opslaan?</translation>
    </message>
    <message>
        <source>&quot;%1&quot; was modified.
Save changes?</source>
        <translation>&quot;%1&quot; is gewijzigd.
Opslaan?</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <source>Writing the database failed.</source>
        <translation>Opslaan van de database is mislukt.</translation>
    </message>
    <message>
        <source>Save database as</source>
        <translation>Database opslaan als</translation>
    </message>
    <message>
        <source>New database</source>
        <translation>Nieuwe database</translation>
    </message>
    <message>
        <source>locked</source>
        <translation>vergrendeld</translation>
    </message>
    <message>
        <source>The database you are trying to open is locked by another instance of KeePassX.
Do you want to open it anyway? Alternatively the database is opened read-only.</source>
        <translation>De database die u probeert te openen is vergrendeld door een andere instantie van KeePassX.
Wilt u toch doorgaan met openen? U kunt de database ook alleen-lezen openen.</translation>
    </message>
    <message>
        <source>Lock database</source>
        <translation>Database vergrendelen</translation>
    </message>
    <message>
        <source>Can't lock the database as you are currently editing it.
Please press cancel to finish your changes or discard them.</source>
        <translation>Kan de database niet vergrendelen omdat u deze momenteel aan het bewerken bent.
Druk op annuleren om uw wijzigingen aan te passen of gooi de wijzigingen weg.</translation>
    </message>
    <message>
        <source>This database has never been saved.
You can save the database or stop locking it.</source>
        <translation>Deze database is nog niet opgeslagen.
U kunt de database opslaan of het vergrendelen annuleren.</translation>
    </message>
    <message>
        <source>This database has been modified.
Do you want to save the database before locking it?
Otherwise your changes are lost.</source>
        <translation>Deze database is gewijzigd.
Wilt u de database opslaan voordat u deze vergrendelt?
Zo nee, dan gaan de wijzigingen verloren.</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is in edit mode.
Discard changes and close anyway?</source>
        <translation>&quot;%1&quot; is gewijzigd.
Wijzigingen ongedaan maken en doorgaan met sluiten?</translation>
    </message>
    <message>
        <source>Export database to CSV file</source>
        <translation>Database exporteren naar CSV-bestand</translation>
    </message>
    <message>
        <source>CSV file</source>
        <translation>CSV-bestand</translation>
    </message>
    <message>
        <source>Writing the CSV file failed.</source>
        <translation>Schrijven van het CSV-bestand mislukt.</translation>
    </message>
    <message>
        <source>The database you are trying to save as is locked by another instance of KeePassX.
Do you want to save it anyway?</source>
        <translation>De database die u op probeert te slaan is vergrendeld door een andere instantie van KeePassX.
Wilt u toch doorgaan met opslaan?</translation>
    </message>
</context>
<context>
    <name>DatabaseWidget</name>
    <message>
        <source>Change master key</source>
        <translation>Wijzig hoofdsleutel</translation>
    </message>
    <message>
        <source>Delete entry?</source>
        <translation>Element verwijderen?</translation>
    </message>
    <message>
        <source>Do you really want to delete the entry &quot;%1&quot; for good?</source>
        <translation>Weet u zeker dat u het element &quot;%1&quot; wilt verwijderen?</translation>
    </message>
    <message>
        <source>Delete entries?</source>
        <translation>Elementen wissen?</translation>
    </message>
    <message>
        <source>Do you really want to delete %1 entries for good?</source>
        <translation>Weet u zeker dat u %1 elementen wilt wissen?</translation>
    </message>
    <message>
        <source>Move entries to recycle bin?</source>
        <translation>Elementen naar de prullenbak verplaatsen?</translation>
    </message>
    <message numerus="yes">
        <source>Do you really want to move %n entry(s) to the recycle bin?</source>
        <translation><numerusform>Weet u zeker dat u %n element naar de prullenbak wilt verplaatsen?</numerusform><numerusform>Weet u zeker dat u %n elementen naar de prullenbak wilt verplaatsen?</numerusform></translation>
    </message>
    <message>
        <source>Delete group?</source>
        <translation>Groep verwijderen?</translation>
    </message>
    <message>
        <source>Do you really want to delete the group &quot;%1&quot; for good?</source>
        <translation>Weet u zeker dat u de groep &quot;%1&quot; wilt verwijderen?</translation>
    </message>
    <message>
        <source>Current group</source>
        <translation>Huidige groep</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Niet mogelijk om hoofdsleutel te berekenen</translation>
    </message>
</context>
<context>
    <name>EditEntryWidget</name>
    <message>
        <source>Entry</source>
        <translation>Element</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Geavanceerd</translation>
    </message>
    <message>
        <source>Icon</source>
        <translation>Icoon</translation>
    </message>
    <message>
        <source>Auto-Type</source>
        <translation>Auto-typen - KeePassX</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Eigenschappen</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Geschiedenis</translation>
    </message>
    <message>
        <source>Entry history</source>
        <translation>Geschiedenis van element</translation>
    </message>
    <message>
        <source>Add entry</source>
        <translation>Element toevoegen</translation>
    </message>
    <message>
        <source>Edit entry</source>
        <translation>Element wijzigen</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <source>Different passwords supplied.</source>
        <translation>Verschillende wachtwoorden opgegeven.</translation>
    </message>
    <message>
        <source>New attribute</source>
        <translation>Nieuwe eigenschap</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation>Kies bestand</translation>
    </message>
    <message>
        <source>Unable to open file</source>
        <translation>Niet mogelijk om bestand te openen</translation>
    </message>
    <message>
        <source>Save attachment</source>
        <translation>Bijlage opslaan</translation>
    </message>
    <message>
        <source>Unable to save the attachment:
</source>
        <translation>Niet mogelijk om de bijlage op te slaan:
</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Morgen</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation><numerusform>%n week</numerusform><numerusform>%n weken</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s)</source>
        <translation><numerusform>%n maand</numerusform><numerusform>%n maanden</numerusform></translation>
    </message>
    <message>
        <source>1 year</source>
        <translation>1 jaar</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetAdvanced</name>
    <message>
        <source>Additional attributes</source>
        <translation>Extra eigenschappen</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Toevoegen</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Wijzigen</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Attachments</source>
        <translation>Bijlagen</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Open</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetAutoType</name>
    <message>
        <source>Enable Auto-Type for this entry</source>
        <translation>Auto-typen inschakelen voor dit element</translation>
    </message>
    <message>
        <source>Inherit default Auto-Type sequence from the group</source>
        <translation>Erf standaard auto-typevolgorde van de groep</translation>
    </message>
    <message>
        <source>Use custom Auto-Type sequence:</source>
        <translation>Gebruik aangepaste auto-typevolgorde:</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Window title:</source>
        <translation>Venstertitel:</translation>
    </message>
    <message>
        <source>Use default sequence</source>
        <translation>Gebruik standaardvolgorde</translation>
    </message>
    <message>
        <source>Set custom sequence:</source>
        <translation>Aangepaste volgorde:</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetHistory</name>
    <message>
        <source>Show</source>
        <translation>Tonen</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Herstellen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Delete all</source>
        <translation>Alles verwijderen</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetMain</name>
    <message>
        <source>Title:</source>
        <translation>Titel:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Gebruikersnaam:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Wachtwoord:</translation>
    </message>
    <message>
        <source>Repeat:</source>
        <translation>Herhalen:</translation>
    </message>
    <message>
        <source>Gen.</source>
        <translation>Gen.</translation>
    </message>
    <message>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Verloopt</translation>
    </message>
    <message>
        <source>Presets</source>
        <translation>Ingebouwd</translation>
    </message>
    <message>
        <source>Notes:</source>
        <translation>Opmerkingen:</translation>
    </message>
</context>
<context>
    <name>EditGroupWidget</name>
    <message>
        <source>Group</source>
        <translation>Groep</translation>
    </message>
    <message>
        <source>Icon</source>
        <translation>Icoon</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Eigenschappen</translation>
    </message>
    <message>
        <source>Add group</source>
        <translation>Groep toevoegen</translation>
    </message>
    <message>
        <source>Edit group</source>
        <translation>Groep wijzigen</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Inschakelen</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Uitschakelen</translation>
    </message>
    <message>
        <source>Inherit from parent group (%1)</source>
        <translation>Erf van bovenliggende groep (%1)</translation>
    </message>
</context>
<context>
    <name>EditGroupWidgetMain</name>
    <message>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <source>Notes</source>
        <translation>Opmerkingen</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Verloopt</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Zoeken</translation>
    </message>
    <message>
        <source>Auto-type</source>
        <translation>Auto-typen</translation>
    </message>
    <message>
        <source>Use default auto-type sequence of parent group</source>
        <translation>Gebruik standaard auto-typevolgorde van bovenliggende groep</translation>
    </message>
    <message>
        <source>Set default auto-type sequence</source>
        <translation>Stel standaard auto-typevolgorde in</translation>
    </message>
</context>
<context>
    <name>EditWidgetIcons</name>
    <message>
        <source>Use default icon</source>
        <translation>Gebruik standaardicoon</translation>
    </message>
    <message>
        <source>Use custom icon</source>
        <translation>Gebruik aangepast icoon</translation>
    </message>
    <message>
        <source>Add custom icon</source>
        <translation>Voeg icoon toe</translation>
    </message>
    <message>
        <source>Delete custom icon</source>
        <translation>Verwijder icoon</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Afbeeldingen</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Alle bestanden</translation>
    </message>
    <message>
        <source>Select Image</source>
        <translation>Kies afbeelding</translation>
    </message>
    <message>
        <source>Can&apos;t delete icon!</source>
        <translation>Kan icoon niet verwijderen!</translation>
    </message>
    <message numerus="yes">
        <source>Can&apos;t delete icon. Still used by %n item(s).</source>
        <translation><numerusform>Kan icoon niet verwijderen. Het wordt nog gebruikt door %n element.</numerusform><numerusform>Kan icoon niet verwijderen. Het wordt nog gebruikt door %n elementen.</numerusform></translation>
    </message>
</context>
<context>
    <name>EditWidgetProperties</name>
    <message>
        <source>Created:</source>
        <translation>Aangemaakt:</translation>
    </message>
    <message>
        <source>Modified:</source>
        <translation>Gewijzigd:</translation>
    </message>
    <message>
        <source>Accessed:</source>
        <translation>Gelezen:</translation>
    </message>
    <message>
        <source>Uuid:</source>
        <translation>Uuid:</translation>
    </message>
</context>
<context>
    <name>EntryAttributesModel</name>
    <message>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
</context>
<context>
    <name>EntryHistoryModel</name>
    <message>
        <source>Last modified</source>
        <translation>Laatst gewijzigd</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Gebruikersnaam</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
</context>
<context>
    <name>EntryModel</name>
    <message>
        <source>Group</source>
        <translation>Groep</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Gebruikersnaam</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
</context>
<context>
    <name>Group</name>
    <message>
        <source>Recycle Bin</source>
        <translation>Prullenbak</translation>
    </message>
</context>
<context>
    <name>KeePass1OpenWidget</name>
    <message>
        <source>Import KeePass1 database</source>
        <translation>Importeer Keepass 1-database</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>Niet mogelijk om de database te openen.</translation>
    </message>
</context>
<context>
    <name>KeePass1Reader</name>
    <message>
        <source>Unable to read keyfile.</source>
        <translation>Niet mogelijk om sleutelbestand te lezen</translation>
    </message>
    <message>
        <source>Not a KeePass database.</source>
        <translation>Geen Keepass-database</translation>
    </message>
    <message>
        <source>Unsupported encryption algorithm.</source>
        <translation>Niet-ondersteund encryptie-algoritme</translation>
    </message>
    <message>
        <source>Unsupported KeePass database version.</source>
        <translation>Niet-ondersteunde versie van Keepass-database</translation>
    </message>
    <message>
        <source>Root</source>
        <translation>Alles</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Niet mogelijk om hoofdsleutel te berekenen</translation>
    </message>
</context>
<context>
    <name>KeePass2Reader</name>
    <message>
        <source>Not a KeePass database.</source>
        <translation>Geen Keepass-database.</translation>
    </message>
    <message>
        <source>Unsupported KeePass database version.</source>
        <translation>Niet-ondersteunde versie van Keepass-database.</translation>
    </message>
    <message>
        <source>Wrong key or database file is corrupt.</source>
        <translation>Verkeerde sleutel of corrupte database.</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Niet mogelijk om hoofdsleutel te berekenen</translation>
    </message>
    <message>
        <source>The selected file is an old KeePass 1 database (.kdb).

You can import it by clicking on Database &gt; 'Import KeePass 1 database'.
This is a one-way migration. You won&apos;t be able to open the imported database with the old KeePassX 0.4 version.</source>
        <translation>Het gekozen bestand is een oude KeePass 1 database (.kdb).

U kunt het importeren door te klikken op Database &gt; &apos;KeePass 1 database importeren&apos;.
Deze actie is niet omkeerbaar. U kunt de geimporteerde database niet meer openen met KeePassX 0.4.</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Fatal error while testing the cryptographic functions.</source>
        <translation>Fatale fout bij het testen van de cryptografische functies.</translation>
    </message>
    <message>
        <source>KeePassX - Error</source>
        <translation>KeePassX - Fout</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Database</source>
        <translation>Database</translation>
    </message>
    <message>
        <source>Recent databases</source>
        <translation>Recente databases</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <source>Entries</source>
        <translation>Elementen</translation>
    </message>
    <message>
        <source>Copy attribute to clipboard</source>
        <translation>Kopieer eigenschap naar klembord</translation>
    </message>
    <message>
        <source>Groups</source>
        <translation>Groepen</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Beeld</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <source>Open database</source>
        <translation>Open database</translation>
    </message>
    <message>
        <source>Save database</source>
        <translation>Sla database op</translation>
    </message>
    <message>
        <source>Close database</source>
        <translation>Sluit database</translation>
    </message>
    <message>
        <source>New database</source>
        <translation>Nieuwe database</translation>
    </message>
    <message>
        <source>Add new entry</source>
        <translation>Voeg element toe</translation>
    </message>
    <message>
        <source>View/Edit entry</source>
        <translation>Bekijk/bewerk element</translation>
    </message>
    <message>
        <source>Delete entry</source>
        <translation>Verwijder element</translation>
    </message>
    <message>
        <source>Add new group</source>
        <translation>Voeg groep toe</translation>
    </message>
    <message>
        <source>Edit group</source>
        <translation>Bewerk groep</translation>
    </message>
    <message>
        <source>Delete group</source>
        <translation>Verwijder groep</translation>
    </message>
    <message>
        <source>Save database as</source>
        <translation>Database opslaan als</translation>
    </message>
    <message>
        <source>Change master key</source>
        <translation>Hoofdsleutel wijzigen</translation>
    </message>
    <message>
        <source>Database settings</source>
        <translation>Database-instellingen</translation>
    </message>
    <message>
        <source>Import KeePass 1 database</source>
        <translation>Importeer Keepass 1-database</translation>
    </message>
    <message>
        <source>Clone entry</source>
        <translation>Element klonen</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Vind</translation>
    </message>
    <message>
        <source>Copy username to clipboard</source>
        <translation>Kopieer gebruikersnaam naar klembord</translation>
    </message>
    <message>
        <source>Copy password to clipboard</source>
        <translation>Kopieer wachtwoord naar klembord</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <source>Perform Auto-Type</source>
        <translation>Voer auto-typen uit</translation>
    </message>
    <message>
        <source>Open URL</source>
        <translation>Open URL</translation>
    </message>
    <message>
        <source>Lock databases</source>
        <translation>Vergrendel databases</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Notes</source>
        <translation>Opmerkingen</translation>
    </message>
    <message>
        <source>Show toolbar</source>
        <translation>Werkbalk weergeven</translation>
    </message>
    <message>
        <source>read-only</source>
        <translation>alleen-lezen</translation>
    </message>
    <message>
        <source>Toggle window</source>
        <translation>Wissel venster</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Hulpmiddelen</translation>
    </message>
    <message>
        <source>Copy username</source>
        <translation>Gebruikersnaam kopieren</translation>
    </message>
    <message>
        <source>Copy password</source>
        <translation>Wachtwoord kopiëren</translation>
    </message>
    <message>
        <source>Export to CSV file</source>
        <translation>Naar CSV-bestand exporteren</translation>
    </message>
    <message>
        <source>Repair database</source>
        <translation>Database repareren</translation>
    </message>
    <message>
        <source>KeePass 2 Database</source>
        <translation>KeePass 2 Database</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Alle bestanden</translation>
    </message>
    <message>
        <source>Save repaired database</source>
        <translation>Gerepareerde database opslaan</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <source>Writing the database failed.</source>
        <translation>Opslaan van de database is mislukt.</translation>
    </message>
</context>
<context>
    <name>PasswordGeneratorWidget</name>
    <message>
        <source>Password:</source>
        <translation>Wachtwoord:</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation>Lengte:</translation>
    </message>
    <message>
        <source>Character Types</source>
        <translation>Tekens</translation>
    </message>
    <message>
        <source>Upper Case Letters</source>
        <translation>Hoofdletters</translation>
    </message>
    <message>
        <source>Lower Case Letters</source>
        <translation>Kleine letters</translation>
    </message>
    <message>
        <source>Numbers</source>
        <translation>Cijfers</translation>
    </message>
    <message>
        <source>Special Characters</source>
        <translation>Speciale tekens</translation>
    </message>
    <message>
        <source>Exclude look-alike characters</source>
        <translation>Geen op elkaar lijkende tekens</translation>
    </message>
    <message>
        <source>Ensure that the password contains characters from every group</source>
        <translation>Zorg dat het wachtwoord tekens uit iedere groep bevat</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>Accepteren</translation>
    </message>
</context>
<context>
    <name>QCommandLineParser</name>
    <message>
        <source>Displays version information.</source>
        <translation>Toont versie-informatie.</translation>
    </message>
    <message>
        <source>Displays this help.</source>
        <translation>Toont deze helptekst.</translation>
    </message>
    <message>
        <source>Unknown option &apos;%1&apos;.</source>
        <translation>Onbekende optie &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Unknown options: %1.</source>
        <translation>Onbekende opties: %1.</translation>
    </message>
    <message>
        <source>Missing value after &apos;%1&apos;.</source>
        <translation>Ontbrekende waarde na &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Unexpected value after &apos;%1&apos;.</source>
        <translation>Onverwachte waarde na &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>[options]</source>
        <translation>[opties]</translation>
    </message>
    <message>
        <source>Usage: %1</source>
        <translation>Gebruik: %1</translation>
    </message>
    <message>
        <source>Options:</source>
        <translation>Opties:</translation>
    </message>
    <message>
        <source>Arguments:</source>
        <translation>Argumenten:</translation>
    </message>
</context>
<context>
    <name>QSaveFile</name>
    <message>
        <source>Existing file %1 is not writable</source>
        <translation>Bestaand bestand %1 is niet schrijfbaar</translation>
    </message>
    <message>
        <source>Writing canceled by application</source>
        <translation>Schrijven afgebroken door programma</translation>
    </message>
    <message>
        <source>Partial write. Partition full?</source>
        <translation>Slechts deels geschreven. Is de schijf vol?</translation>
    </message>
</context>
<context>
    <name>QtIOCompressor</name>
    <message>
        <source>Internal zlib error when compressing: </source>
        <translation>Interne fout in zlib bij inpakken:</translation>
    </message>
    <message>
        <source>Error writing to underlying device: </source>
        <translation>Fout bij schrijven naar onderliggend apparaat:</translation>
    </message>
    <message>
        <source>Error opening underlying device: </source>
        <translation>Fout bij openen van onderliggend apparaat:</translation>
    </message>
    <message>
        <source>Error reading data from underlying device: </source>
        <translation>Fout bij lezen van gegevens van onderliggend apparaat:</translation>
    </message>
    <message>
        <source>Internal zlib error when decompressing: </source>
        <translation>Interne fout in zlib bij uitpakken:</translation>
    </message>
</context>
<context>
    <name>QtIOCompressor::open</name>
    <message>
        <source>The gzip format not supported in this version of zlib.</source>
        <translation>Gzip wordt niet ondersteund in deze versie van zlib.</translation>
    </message>
    <message>
        <source>Internal zlib error: </source>
        <translation>Interne fout in zlib:</translation>
    </message>
</context>
<context>
    <name>SearchWidget</name>
    <message>
        <source>Find:</source>
        <translation>Vind:</translation>
    </message>
    <message>
        <source>Case sensitive</source>
        <translation>Hoofdlettergevoelig</translation>
    </message>
    <message>
        <source>Current group</source>
        <translation>Huidige groep</translation>
    </message>
    <message>
        <source>Root group</source>
        <translation>Hoofdgroep</translation>
    </message>
</context>
<context>
    <name>SettingsWidget</name>
    <message>
        <source>Application Settings</source>
        <translation>Programma-instellingen</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Algemeen</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Beveiliging</translation>
    </message>
</context>
<context>
    <name>SettingsWidgetGeneral</name>
    <message>
        <source>Remember last databases</source>
        <translation>Onthoud laatste databases</translation>
    </message>
    <message>
        <source>Open previous databases on startup</source>
        <translation>Open vorige databases bij starten</translation>
    </message>
    <message>
        <source>Automatically save on exit</source>
        <translation>Automatisch opslaan bij afsluiten</translation>
    </message>
    <message>
        <source>Automatically save after every change</source>
        <translation>Automatisch opslaan na iedere wijziging</translation>
    </message>
    <message>
        <source>Minimize when copying to clipboard</source>
        <translation>Minimaliseer bij kopiëren naar klembord</translation>
    </message>
    <message>
        <source>Use group icon on entry creation</source>
        <translation>Gebruik icoon van de groep voor nieuwe elementen</translation>
    </message>
    <message>
        <source>Global Auto-Type shortcut</source>
        <translation>Globale sneltoets voor auto-typen</translation>
    </message>
    <message>
        <source>Use entry title to match windows for global auto-type</source>
        <translation>Gebruik naam van element als vensternaam voor auto-typen</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Taal</translation>
    </message>
    <message>
        <source>Show a system tray icon</source>
        <translation>Toon een icoon in de systray</translation>
    </message>
    <message>
        <source>Hide window to system tray when minimized</source>
        <translation>Bij minimaliseren enkel icoon in systray tonen</translation>
    </message>
    <message>
        <source>Remember last key files</source>
        <translation>Onthoud laatste sleutelbestanden</translation>
    </message>
</context>
<context>
    <name>SettingsWidgetSecurity</name>
    <message>
        <source>Clear clipboard after</source>
        <translation>Leeg klembord na</translation>
    </message>
    <message>
        <source> sec</source>
        <translation>sec</translation>
    </message>
    <message>
        <source>Lock databases after inactivity of</source>
        <translation>Vergrendel databases na inactiviteit van</translation>
    </message>
    <message>
        <source>Show passwords in cleartext by default</source>
        <translation>Laat wachtwoorden standaard zien</translation>
    </message>
    <message>
        <source>Always ask before performing auto-type</source>
        <translation>Altijd vragen alvorens auto-type uit te voeren</translation>
    </message>
</context>
<context>
    <name>UnlockDatabaseWidget</name>
    <message>
        <source>Unlock database</source>
        <translation>Database ontgrendelen</translation>
    </message>
</context>
<context>
    <name>WelcomeWidget</name>
    <message>
        <source>Welcome!</source>
        <translation>Welkom!</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>KeePassX - cross-platform password manager</source>
        <translation>KeepassX - multi-platform wachtwoordbeheerder</translation>
    </message>
    <message>
        <source>filename of the password database to open (*.kdbx)</source>
        <translation>bestandsnaam van de te openen wachtwoorddatabase (*.kdbx)</translation>
    </message>
    <message>
        <source>path to a custom config file</source>
        <translation>pad naar een configuratiebestand</translation>
    </message>
    <message>
        <source>key file of the database</source>
        <translation>sleutelbestand van de database</translation>
    </message>
</context>
</TS>